Description
Calculates the marginal likelihood of M_excl
Usage
M_excl(Q, l, m, n, N = sum(Q), S = sum(Q))
Arguments
Q
Histogram of dataset (l\*m\*n vector)
N
Number of Repetitions for Nested Sampling
S
Number of Starting Points for Nested Sampling
Value
The probability that the observations where created from a model which violates the exclusion criterion but not the as-if-randomness criterion