Learn R Programming

npsr (version 0.1.1)

nps.necessary: testIc

Description

Tests the instrumental constraints on the given dataframe using entropy

Usage

nps.necessary(df)

Arguments

df

Dataframe with z, x and y

Value

FALSE if the data violates the constraints otherwise TRUE