Learn R Programming

npsr (version 0.1.1)

product_fraction: Reduces out factors of fraction of products and calculates the fraction Analog to prod(num)/prod(den)

Description

Reduces out factors of fraction of products and calculates the fraction Analog to prod(num)/prod(den)

Usage

product_fraction(num, den)

Arguments

num

vector of factors of the numerator

den

vector of factors of the denominator